@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004-2010 by Martin Preuss
+    copyright   : (C) 2021 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -15,28 +15,32 @@
 
 
 #include "global.h"
-#include <time.h>
-#include <assert.h>
-#include <chipcard/client.h>
+
+#include <libchipcard/base/client.h>
+
 #include <gwenhywfar/debug.h>
 
+#include <time.h>
+#include <assert.h>
 
 
-int getAtr(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
-  LC_CLIENT_RESULT res;
+
+int getAtr(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs)
+{
+  int res;
   int timeOut;
   LC_CARD *card=NULL;
 
   timeOut=GWEN_DB_GetIntValue(dbArgs, "timeout", 0, CARD_TIMEOUT);
 
   res=LC_Client_Start(cl);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(0, res, "StartWait");
     return 2;
   }
 
   res=LC_Client_GetNextCard(cl, &card, timeOut);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(0, res, "GetNextCard");
     return 2;
   }
@@ -48,14 +52,14 @@ int getAtr(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   LC_Card_Dump(card, 2);
 
   res=LC_Client_ReleaseCard(cl, card);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(0, res, "ReleaseCard");
     return 2;
   }
   LC_Card_free(card);
 
   res=LC_Client_Stop(cl);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(0, res, "StopWait");
     return 2;
   }
