@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile: global.h,v $
-                             -------------------
-    cvs         : $Id: global.h,v 1.2 2005/01/24 23:53:35 aquamaniac Exp $
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2021 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -15,9 +12,8 @@
 #define RSACARD_GLOBAL_H
 
 
-#include <chipcard2/chipcard2.h>
-#include <chipcard2-client/client/client.h>
-#include <chipcard2-client/cards/geldkarte.h>
+#include <libchipcard/chipcard.h>
+#include <libchipcard/base/client.h>
 
 #include <gwenhywfar/logger.h>
 #include <gwenhywfar/db.h>
@@ -25,7 +21,6 @@
 #define I18N(msg) msg
 
 #define LISTREADERS_TIMEOUT 5
-#define CHECKREADERS_TIMEOUT 15
 #define CARD_TIMEOUT 30
 
 #define RETURNVALUE_PARAM   1
@@ -34,10 +29,8 @@
 #define RETURNVALUE_DEINIT  4
 
 
-void showError(LC_CARD *card, LC_CLIENT_RESULT res, const char *x);
+void showError(LC_CARD *card, int res, const char *x);
 
-int listReaders(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs);
-int checkReaders(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs);
 int getAtr(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs);
 
 
