@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004-2010 by Martin Preuss
+    copyright   : (C) 2021 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -12,9 +12,9 @@
 #define RSACARD_GLOBAL_H
 
 
-#include <chipcard/chipcard.h>
-#include <chipcard/client.h>
-#include <chipcard/cards/memorycard.h>
+#include <libchipcard/chipcard.h>
+#include <libchipcard/base/client.h>
+#include <libchipcard/cards/memorycard/memorycard.h>
 
 #include <gwenhywfar/logger.h>
 
@@ -25,7 +25,7 @@
 #define RETURNVALUE_DEINIT  4
 
 
-void showError(LC_CARD *card, LC_CLIENT_RESULT res, const char *x);
+void showError(LC_CARD *card, int res, const char *x);
 
 int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs);
 int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs);
