@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2021 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -37,122 +34,123 @@
     "See COPYING for details.\n"
 
 
-const GWEN_ARGS prg_args[]={
-{
-  GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
-  GWEN_ArgsType_Char,            /* type */
-  "logtype",                    /* name */
-  0,                            /* minnum */
-  1,                            /* maxnum */
-  0,                            /* short option */
-  "logtype",                    /* long option */
-  "Set the logtype",            /* short description */
-  "Set the logtype (console, file)."
-},
-{
-  GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
-  GWEN_ArgsType_Char,            /* type */
-  "loglevel",                   /* name */
-  0,                            /* minnum */
-  1,                            /* maxnum */
-  0,                            /* short option */
-  "loglevel",                   /* long option */
-  "Set the log level",          /* short description */
-  "Set the log level (info, notice, warning, error)."
-},
-{
-  GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
-  GWEN_ArgsType_Char,            /* type */
-  "logfile",                    /* name */
-  0,                            /* minnum */
-  1,                            /* maxnum */
-  0,                            /* short option */
-  "logfile",                   /* long option */
-  "Set the log file",          /* short description */
-  "Set the log file (if log type is \"file\")."
-},
-{
-  0,                            /* flags */
-  GWEN_ArgsType_Int,             /* type */
-  "verbosity",                  /* name */
-  0,                            /* minnum */
-  10,                           /* maxnum */
-  "v",                          /* short option */
-  "verbous",                    /* long option */
-  "Increase the verbosity",     /* short description */
-  "Every occurrence of this option increases the verbosity."
-},
-{
-  0,                            /* flags */
-  GWEN_ArgsType_Int,             /* type */
-  "verify",                     /* name */
-  0,                            /* minnum */
-  1,                            /* maxnum */
-  0,                            /* short option */
-  "verify",                     /* long option */
-  "Verify written data",     /* short description */
-  "Verify data after writing it to the card."
-},
-{
-  GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
-  GWEN_ArgsType_Int,             /* type */
-  "offset",                     /* name */
-  0,                            /* minnum */
-  1,                            /* maxnum */
-  "a",                          /* short option */
-  "offset",                     /* long option */
-  "offset to start reading/writing at",      /* short description */
-  "Offset to start reading/writing at."
-},
-{
-  GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
-  GWEN_ArgsType_Int,             /* type */
-  "size",                       /* name */
-  1,                            /* minnum */
-  1,                            /* maxnum */
-  "s",                          /* short option */
-  "size",                       /* long option */
-  "number of bytes to read/write",  /* short description */
-  "Number of bytes to read/write.", /* long description */
-},
-{
-  GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
-  GWEN_ArgsType_Char,            /* type */
-  "filename",                   /* name */
-  0,                            /* minnum */
-  1,                            /* maxnum */
-  "f",                          /* short option */
-  "filename",                   /* long option */
-  "File to read/write",         /* short description */
-  "File to read/write."
-},
-{
-  GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
-  GWEN_ArgsType_Char,            /* type */
-  "pin",                        /* name */
-  0,                            /* minnum */
-  1,                            /* maxnum */
-  "p",                          /* short option */
-  "pin",                        /* long option */
-  "Pin",                        /* short description */
-  "Pin."
-},
-{
-  GWEN_ARGS_FLAGS_HELP | GWEN_ARGS_FLAGS_LAST, /* flags */
-  GWEN_ArgsType_Int,             /* type */
-  "help",                       /* name */
-  0,                            /* minnum */
-  0,                            /* maxnum */
-  "h",                          /* short option */
-  "help",                       /* long option */
-  "Show help",                  /* short description */
-  "Shows this help."            /* long description */
+const GWEN_ARGS prg_args[]= {
+  {
+    GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
+    GWEN_ArgsType_Char,            /* type */
+    "logtype",                    /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    0,                            /* short option */
+    "logtype",                    /* long option */
+    "Set the logtype",            /* short description */
+    "Set the logtype (console, file)."
+  },
+  {
+    GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
+    GWEN_ArgsType_Char,            /* type */
+    "loglevel",                   /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    0,                            /* short option */
+    "loglevel",                   /* long option */
+    "Set the log level",          /* short description */
+    "Set the log level (info, notice, warning, error)."
+  },
+  {
+    GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
+    GWEN_ArgsType_Char,            /* type */
+    "logfile",                    /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    0,                            /* short option */
+    "logfile",                   /* long option */
+    "Set the log file",          /* short description */
+    "Set the log file (if log type is \"file\")."
+  },
+  {
+    0,                            /* flags */
+    GWEN_ArgsType_Int,             /* type */
+    "verbosity",                  /* name */
+    0,                            /* minnum */
+    10,                           /* maxnum */
+    "v",                          /* short option */
+    "verbous",                    /* long option */
+    "Increase the verbosity",     /* short description */
+    "Every occurrence of this option increases the verbosity."
+  },
+  {
+    0,                            /* flags */
+    GWEN_ArgsType_Int,             /* type */
+    "verify",                     /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    0,                            /* short option */
+    "verify",                     /* long option */
+    "Verify written data",     /* short description */
+    "Verify data after writing it to the card."
+  },
+  {
+    GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
+    GWEN_ArgsType_Int,             /* type */
+    "offset",                     /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    "a",                          /* short option */
+    "offset",                     /* long option */
+    "offset to start reading/writing at",      /* short description */
+    "Offset to start reading/writing at."
+  },
+  {
+    GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
+    GWEN_ArgsType_Int,             /* type */
+    "size",                       /* name */
+    1,                            /* minnum */
+    1,                            /* maxnum */
+    "s",                          /* short option */
+    "size",                       /* long option */
+    "number of bytes to read/write",  /* short description */
+    "Number of bytes to read/write.", /* long description */
+  },
+  {
+    GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
+    GWEN_ArgsType_Char,            /* type */
+    "filename",                   /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    "f",                          /* short option */
+    "filename",                   /* long option */
+    "File to read/write",         /* short description */
+    "File to read/write."
+  },
+  {
+    GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
+    GWEN_ArgsType_Char,            /* type */
+    "pin",                        /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    "p",                          /* short option */
+    "pin",                        /* long option */
+    "Pin",                        /* short description */
+    "Pin."
+  },
+  {
+    GWEN_ARGS_FLAGS_HELP | GWEN_ARGS_FLAGS_LAST, /* flags */
+    GWEN_ArgsType_Int,             /* type */
+    "help",                       /* name */
+    0,                            /* minnum */
+    0,                            /* maxnum */
+    "h",                          /* short option */
+    "help",                       /* long option */
+    "Show help",                  /* short description */
+    "Shows this help."            /* long description */
   }
 };
 
 
-void usage(const char *ustr) {
-  fprintf(stdout,"%s%s",
+void usage(const char *ustr)
+{
+  fprintf(stdout, "%s%s",
           I18N("MemCard2 - A tool to read/write data from/to a memory chip card\n"
                "(c) 2006 Martin Preuss<martin@libchipcard.de>\n"
                "This library is free software; you can redistribute it and/or\n"
@@ -165,66 +163,17 @@ void usage(const char *ustr) {
 
 
 
-void showError(LC_CARD *card, LC_CLIENT_RESULT res, const char *x) {
-  const char *s;
-
-  switch(res) {
-  case LC_Client_ResultOk:
-    s="Ok.";
-    break;
-  case LC_Client_ResultWait:
-    s="Timeout.";
-    break;
-  case LC_Client_ResultIpcError:
-    s="IPC error.";
-    break;
-  case LC_Client_ResultCmdError:
-    s="Command error.";
-    break;
-  case LC_Client_ResultDataError:
-    s="Data error.";
-    break;
-  case LC_Client_ResultAborted:
-    s="Aborted.";
-    break;
-  case LC_Client_ResultInvalid:
-    s="Invalid argument to command.";
-    break;
-  case LC_Client_ResultInternal:
-    s="Internal error.";
-    break;
-  case LC_Client_ResultGeneric:
-    s="Generic error.";
-    break;
-  default:
-    s="Unknown error.";
-    break;
-  }
-
-  fprintf(stderr, "Error in \"%s\": %s\n", x, s);
-  if (card && res==LC_Client_ResultCmdError) {
-    int sw1;
-    int sw2;
-
-    sw1=LC_Card_GetLastSW1(card);
-    sw2=LC_Card_GetLastSW2(card);
-    fprintf(stderr, "  Last card command result:\n");
-    if (sw1!=-1 && sw2!=-1)
-      fprintf(stderr, "   SW1=%02x, SW2=%02x\n", sw1, sw2);
-    s=LC_Card_GetLastResult(card);
-    if (s)
-      fprintf(stderr, "   Result: %s\n", s);
-    s=LC_Card_GetLastText(card);
-    if (s)
-      fprintf(stderr, "   Text  : %s\n", s);
-  }
+void showError(LC_CARD *card, int res, const char *x)
+{
+  LC_Card_PrintResult(card, x, res);
 }
 
 
 
-int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
+int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs)
+{
   LC_CARD *card=0;
-  LC_CLIENT_RESULT res;
+  int res;
   int rv;
   int v;
   const char *s;
@@ -243,18 +192,18 @@ int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   if (v>1)
     fprintf(stderr, "Connecting to server.\n");
   res=LC_Client_Start(cl);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(card, res, "StartWait");
     return RETURNVALUE_WORK;
   }
   if (v>1)
     fprintf(stderr, "Connected.\n");
 
-  for (i=0;;i++) {
+  for (i=0;; i++) {
     if (v>0)
       fprintf(stderr, "Waiting for card...\n");
     res=LC_Client_GetNextCard(cl, &card, 20);
-    if (res!=LC_Client_ResultOk) {
+    if (res<0) {
       showError(card, res, "GetNextCard");
       return RETURNVALUE_WORK;
     }
@@ -269,7 +218,7 @@ int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
     if (v>0)
       fprintf(stderr, "Not a memory card, releasing.\n");
     res=LC_Client_ReleaseCard(cl, card);
-    if (res!=LC_Client_ResultOk) {
+    if (res<0) {
       showError(card, res, "ReleaseCard");
       return RETURNVALUE_WORK;
     }
@@ -292,7 +241,7 @@ int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   if (v>0)
     fprintf(stderr, "Opening card.\n");
   res=LC_Card_Open(card);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     fprintf(stderr,
             "ERROR: Error executing command CardOpen (%d).\n",
             res);
@@ -305,7 +254,7 @@ int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   if (v>1)
     fprintf(stderr, "Telling the server that we need no more cards.\n");
   res=LC_Client_Stop(cl);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(card, res, "Stop");
     LC_Client_ReleaseCard(cl, card);
     return RETURNVALUE_WORK;
@@ -317,7 +266,7 @@ int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
     f=stdout;
   }
   else {
-    f=fopen(fname,"w+");
+    f=fopen(fname, "w+");
   }
   if (!f) {
     fprintf(stderr,
@@ -340,7 +289,7 @@ int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   bps=0;
   t0=time(0);
   i=size;
-  while(i) {
+  while (i) {
     int t;
 
     if (i>1024)
@@ -364,7 +313,7 @@ int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
                                  t,
                                  buf);
 
-    if (res!=LC_Client_ResultOk) {
+    if (res<0) {
       showError(card, res, "ReadBinary");
       if (fname)
         fclose(f);
@@ -423,18 +372,17 @@ int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   if (v>0)
     fprintf(stderr, "Closing card.\n");
   res=LC_Card_Close(card);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(card, res, "CardClose");
     return RETURNVALUE_WORK;
   }
-  else
-    if (v>1)
-      fprintf(stderr, "Card closed.\n");
+  else if (v>1)
+    fprintf(stderr, "Card closed.\n");
 
   if (v>0)
     fprintf(stderr, "Releasing card.\n");
   res=LC_Client_ReleaseCard(cl, card);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(card, res, "ReleaseCard");
     return RETURNVALUE_WORK;
   }
@@ -448,9 +396,10 @@ int memRead(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
 
 
 
-int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
+int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs)
+{
   LC_CARD *card=0;
-  LC_CLIENT_RESULT res;
+  int res;
   int rv;
   int v;
   const char *s;
@@ -474,7 +423,7 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
     f=stdin;
   }
   else {
-    f=fopen(fname,"r");
+    f=fopen(fname, "r");
   }
   if (!f) {
     fprintf(stderr,
@@ -486,7 +435,7 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   if (v>1)
     fprintf(stderr, "Connecting to server.\n");
   res=LC_Client_Start(cl);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(card, res, "StartWait");
     if (fname)
       fclose(f);
@@ -495,11 +444,11 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   if (v>1)
     fprintf(stderr, "Connected.\n");
 
-  for (i=0;;i++) {
+  for (i=0;; i++) {
     if (v>0)
       fprintf(stderr, "Waiting for card...\n");
     res=LC_Client_GetNextCard(cl, &card, 20);
-    if (res!=LC_Client_ResultOk) {
+    if (res<0) {
       showError(card, res, "GetNextCard");
       if (fname)
         fclose(f);
@@ -516,7 +465,7 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
     if (v>0)
       fprintf(stderr, "Not a memory card, releasing.\n");
     res=LC_Client_ReleaseCard(cl, card);
-    if (res!=LC_Client_ResultOk) {
+    if (res<0) {
       showError(card, res, "ReleaseCard");
       if (fname)
         fclose(f);
@@ -546,7 +495,7 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   if (v>0)
     fprintf(stderr, "Opening card.\n");
   res=LC_Card_Open(card);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     fprintf(stderr,
             "ERROR: Error executing command CardOpen (%d).\n",
             res);
@@ -562,7 +511,7 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   if (v>1)
     fprintf(stderr, "Telling the server that we need no more cards.\n");
   res=LC_Client_Stop(cl);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(card, res, "Stop");
     if (fname)
       fclose(f);
@@ -580,7 +529,7 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   bps=0;
   t0=time(0);
   i=size;
-  while(i) {
+  while (i) {
     int t;
     char buf[1024];
 
@@ -616,12 +565,11 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
     }
 
     /* write bytes */
-    res=LC_Client_ResultOk;
     res=LC_MemoryCard_WriteBinary(card,
                                   offset,
                                   buf,
                                   t);
-    if (res!=LC_Client_ResultOk) {
+    if (res<0) {
       showError(card, res, "WriteBinary");
       if (fname)
         fclose(f);
@@ -643,7 +591,7 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
                                    t,
                                    tbuf);
 
-      if (res!=LC_Client_ResultOk) {
+      if (res<0) {
         showError(card, res, "ReadBinary");
         if (fname)
           fclose(f);
@@ -699,22 +647,20 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
   if (v>0)
     fprintf(stderr, "Closing card.\n");
   res=LC_Card_Close(card);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(card, res, "CardClose");
     return RETURNVALUE_WORK;
   }
-  else
-    if (v>1)
-      fprintf(stderr, "Card closed.\n");
+  else if (v>1)
+    fprintf(stderr, "Card closed.\n");
 
   res=LC_Client_ReleaseCard(cl, card);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(card, res, "ReleaseCard");
     return RETURNVALUE_WORK;
   }
-  else
-    if (v>1)
-      fprintf(stderr, "Card released.\n");
+  else if (v>1)
+    fprintf(stderr, "Card released.\n");
 
   /* finished */
   if (v>1)
@@ -724,14 +670,15 @@ int memWrite(LC_CLIENT *cl, GWEN_DB_NODE *dbArgs){
 
 
 
-int main(int argc, char **argv) {
+int main(int argc, char **argv)
+{
   int rv;
   GWEN_DB_NODE *db;
   const char *s;
   LC_CLIENT *cl;
   GWEN_LOGGER_LOGTYPE logType;
   GWEN_LOGGER_LEVEL logLevel;
-  LC_CLIENT_RESULT res;
+  int res;
   GWEN_GUI *gui;
 
   gui=GWEN_Gui_CGui_new();
@@ -775,9 +722,9 @@ int main(int argc, char **argv) {
   }
   rv=GWEN_Logger_Open(LC_LOGDOMAIN,
                       "memcard3",
-		      GWEN_DB_GetCharValue(db, "logfile", 0, "memcard3.log"),
-		      logType,
-		      GWEN_LoggerFacility_User);
+                      GWEN_DB_GetCharValue(db, "logfile", 0, "memcard3.log"),
+                      logType,
+                      GWEN_LoggerFacility_User);
   if (rv) {
     fprintf(stderr, "ERROR: Could not setup logging (%d).\n", rv);
     return RETURNVALUE_SETUP;
@@ -794,7 +741,7 @@ int main(int argc, char **argv) {
 
   cl=LC_Client_new("memcard", PROGRAM_VERSION);
   res=LC_Client_Init(cl);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(0, res, "Init");
     return RETURNVALUE_SETUP;
   }
@@ -812,7 +759,7 @@ int main(int argc, char **argv) {
   }
 
   res=LC_Client_Fini(cl);
-  if (res!=LC_Client_ResultOk) {
+  if (res<0) {
     showError(0, res, "Init");
   }
 
